@@ -2,12 +2,12 @@ from __future__ import absolute_import, division, unicode_literals
 
 from copy import copy
 
-from numpy import asarray, clip, dot, exp, finfo, inf, log, zeros
+from numpy import asarray, clip, dot, exp, finfo, log, zeros
 from numpy_sugar import epsilon
 from numpy_sugar.linalg import ddot, sum2diag
 from optimix import Function, Scalar, Vector
 
-from ..check import check_covariates, check_economic_qs, check_outcome
+from ..util import check_covariates, check_economic_qs, check_outcome
 
 
 class GLMM(Function):
